@@ -1,13 +1,18 @@
 import pytest
+from fake_kubernetes_client import FakeDynamicClient
 from ocp_resources.api_server import APIServer
 
 
 @pytest.mark.incremental
 class TestAPIServer:
     @pytest.fixture(scope="class")
-    def apiserver(self, fake_client):
+    def client(self):
+        return FakeDynamicClient()
+
+    @pytest.fixture(scope="class")
+    def apiserver(self, client):
         return APIServer(
-            client=fake_client,
+            client=client,
             name="test-apiserver",
         )
 
