@@ -1,13 +1,18 @@
 import pytest
+from fake_kubernetes_client import FakeDynamicClient
 from ocp_resources.authorino import Authorino
 
 
 @pytest.mark.incremental
 class TestAuthorino:
     @pytest.fixture(scope="class")
-    def authorino(self, fake_client):
+    def client(self):
+        return FakeDynamicClient()
+
+    @pytest.fixture(scope="class")
+    def authorino(self, client):
         return Authorino(
-            client=fake_client,
+            client=client,
             name="test-authorino",
             namespace="default",
             listener={"test-listener": "test-value"},
